﻿using System.Collections.ObjectModel;
using System.Windows;
using ThinkGeo.MapSuite;
using ThinkGeo.MapSuite.Layers;
using ThinkGeo.MapSuite.Shapes;
using ThinkGeo.MapSuite.Styles;
using ThinkGeo.MapSuite.Wpf;

namespace _15floors
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        InMemoryFeatureLayer inmemoryFeatureLayer = new InMemoryFeatureLayer();
        private PointShape _LastMapClickLocation;
        const string PopupOverlayName = "PopupOverlay";

        public MainWindow()
        {
            InitializeComponent();
        }

        private void map_Loaded(object sender, RoutedEventArgs e)
        {
            Map1.MapUnit = GeographyUnit.Meter;
            LayerOverlay myOverlay = new LayerOverlay();
            Map1.Overlays.Add(myOverlay);

            myOverlay.TileCache = new FileBitmapTileCache(@"..\..\Cache\");

            string[] files = new string[0];//System.IO.Directory.GetFiles(@"C:\Users\User\Desktop\DSI REFERENCE\Map Data\Raster");

            foreach (string file in files)
            {
                GeoTiffRasterLayer tiffLayer = new GeoTiffRasterLayer(file);

                myOverlay.Layers.Add(tiffLayer);
            }
            myOverlay.Open();
            Map1.CurrentExtent = myOverlay.GetBoundingBox();

            PopupOverlay popupOverlay = new PopupOverlay();
            Map1.Overlays.Add("PopupOverlay", popupOverlay);

            //Show a popup on "Real" world

            InMemoryFeatureLayer inmemoryFeatureLayer = new InMemoryFeatureLayer();
            inmemoryFeatureLayer.ZoomLevelSet.ZoomLevel01.DefaultPointStyle = PointStyles.City1;//new PointStyle(new GeoImage(@"C:\Users\User\Downloads\15floors\Icon\Point.png"));

            inmemoryFeatureLayer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;

            LayerOverlay markerOverlay = new LayerOverlay();
            markerOverlay.Layers.Add("InMemoryFeatureLayer", inmemoryFeatureLayer);
            Map1.Overlays.Add("MarkerOverlay", markerOverlay);

            Map1.Refresh();
        }

        private void Map1_MapClick(object sender, MapClickWpfMapEventArgs e)
        {
            _LastMapClickLocation = e.WorldLocation;
            LayerOverlay markerOverlay = (LayerOverlay)Map1.Overlays["MarkerOverlay"];
            InMemoryFeatureLayer inmemoryFeatureLayer = markerOverlay.Layers[0] as InMemoryFeatureLayer;

            MultipolygonShape buffer = e.WorldLocation.Buffer(350, GeographyUnit.Meter, DistanceUnit.Kilometer);

            inmemoryFeatureLayer.InternalFeatures.Add(new Feature(e.WorldLocation));

            Map1.Refresh();
        }



        private void delete_ButtonClick(object sender, RoutedEventArgs e)
        {
            LayerOverlay markerOverlay = (LayerOverlay)Map1.Overlays["MarkerOverlay"];
            InMemoryFeatureLayer inmemoryFeatureLayer = markerOverlay.Layers[0] as InMemoryFeatureLayer;
            inmemoryFeatureLayer.Open();
            Collection<Feature> neartestFeatures = inmemoryFeatureLayer.QueryTools.GetFeaturesNearestTo(_LastMapClickLocation, GeographyUnit.Meter, 10, ReturningColumnsType.AllColumns);
            if (neartestFeatures.Count > 0)
            {
                inmemoryFeatureLayer.InternalFeatures.Remove(neartestFeatures[neartestFeatures.Count - 1]);                
            }

            Map1.Refresh();
        }

        private void Clear_ButtonClick(object sender, RoutedEventArgs e)
        {
            LayerOverlay markerOverlay = (LayerOverlay)Map1.Overlays["MarkerOverlay"];
            InMemoryFeatureLayer inmemoryFeatureLayer = markerOverlay.Layers[0] as InMemoryFeatureLayer;
            inmemoryFeatureLayer.Clear();

            Map1.Refresh();
        }



    }
}
